@@ -59,8 +59,6 @@ public:
     void unregisterWindowId(qlonglong windowId, const QString &sender);
     //@}
     void recreate(bool initial);
-    // TODO KF6 remove
-    void loadSecondPhase();
 
     //@{
     /**
@@ -136,11 +134,6 @@ public Q_SLOTS:
      */
     void slotApplicationRemoved(const QString &);
 
-    /**
-     * A KDEDModule is about to get destroyed.
-     */
-    void slotKDEDModuleRemoved(KDEDModule *);
-
 protected Q_SLOTS:
 
     /**
@@ -179,13 +172,13 @@ protected:
 
     KDEDModule *loadModule(const KPluginMetaData &module, bool onDemand);
 
-    QVector<KPluginMetaData> availableModules() const;
+    QList<KPluginMetaData> availableModules() const;
     /**
      * Pointer to the dirwatch class which tells us, when some directories
      * changed.
      * Slower polling for remote file systems is now done in KDirWatch (JW).
      */
-    KDirWatch *m_pDirWatch;
+    KDirWatch *m_pDirWatch = nullptr;
 
     /**
      * When a desktop file is updated, a timer is started (5 sec)
@@ -209,19 +202,6 @@ protected:
     static Kded *_self;
 };
 
-class KBuildsycocaAdaptor : public QDBusAbstractAdaptor
-{
-    Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.kbuildsycoca")
-public:
-    KBuildsycocaAdaptor(QObject *parent);
-
-public Q_SLOTS:
-    void recreate();
-    bool isTestModeEnabled();
-    void setTestModeEnabled();
-};
-
 class KUpdateD : public QObject
 {
     Q_OBJECT
@@ -239,7 +219,7 @@ private:
      * changed.
      * Slower polling for remote file systems is now done in KDirWatch (JW).
      */
-    KDirWatch *m_pDirWatch;
+    KDirWatch *m_pDirWatch = nullptr;
 
     /**
      * When a desktop file is updated, a timer is started (5 sec)
